@@ -5,26 +5,17 @@ hio.core.http.clienting module
 nonblocking http client
 """
 
-import sys
-import os
-import socket
-import errno
-import io
-from collections import deque, namedtuple
-import codecs
 import json
-import ssl
 import copy
 import random
-import datetime
-import time
 
+from collections import deque, namedtuple
 from urllib.parse import urlsplit, quote, quote_plus, unquote, unquote_plus
+from contextlib import contextmanager
 
 from ... import help
-from ...help import helping
-from ...base import tyming
-from .. import coring
+from ...base import tyming, doing
+from .. import coring, wiring
 from .. import tcp
 from . import httping
 
@@ -80,7 +71,7 @@ class Requester(object):
         self.path = path or u'/'
         self.qargs = qargs if qargs is not None else dict()
         self.fragment = fragment
-        self.headers = helping.imdict(headers) if headers else helping.imdict()
+        self.headers = help.Hict(headers) if headers else help.Hict()
         if body and isinstance(body, str):  # use default
             # RFC 2616 Section 3.7.1 default charset of iso-8859-1.
             body = body.encode('iso-8859-1')
@@ -123,7 +114,7 @@ class Requester(object):
         if fragment is not None:
             self.fragment = fragment
         if headers is not None:
-            self.headers = helping.imdict(headers)
+            self.headers = help.Hict(headers)
         if body is not None:  # body should be bytes
             if isinstance(body, str):
                 # RFC 2616 Section 3.7.1 default charset of iso-8859-1.
@@ -399,7 +390,7 @@ class Respondent(httping.Parsent):
         if self.headed:
             return  # already parsed the head
 
-        self.headers = helping.imdict()
+        self.headers = help.Hict()
 
         # create generator
         lineParser = httping.parseLine(raw=self.msg, eols=(CRLF, LF), kind="status line")
@@ -606,6 +597,36 @@ class Respondent(httping.Parsent):
         return
 
 
+
+@contextmanager
+def openClient(cls=None, **kwa):
+    """
+    Wrapper to create and open HTTP Client instances
+    When used in with statement block, calls .close() on exit of with block
+
+    Parameters:
+        cls is Class instance of subclass instance
+
+    Usage:
+        with openClient() as client0:
+            client0.accept()
+
+        with openClient(cls=Client) as client0:
+            client0.accept()
+
+    """
+    if cls is None:
+        cls = Client
+    try:
+        client = cls(**kwa)
+        client.reopen()
+
+        yield client
+
+    finally:
+        client.close()
+
+
 class Client():
     """
     Client class nonblocking HTTP client connection manager and HTTP client
@@ -806,7 +827,16 @@ class Client():
         self.respondent = respondent
 
 
-    def open(self):
+    def wind(self, tymth):
+        """
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
+        """
+        if self.connector:
+            self.connector.wind(tymth)
+
+
+    def reopen(self):
         """
         Return result of .connector.reopen()
         """
@@ -871,7 +901,7 @@ class Client():
         request["path"] = path if path is not None else self.requester.path
         request["qargs"] = qargs if qargs is not None else self.requester.qargs.copy()
         request["fragment"] = fragment if qargs is not None else self.requester.fragment
-        request["headers"] = helping.imdict(headers) if headers is not None else self.requester.headers.copy()
+        request["headers"] = help.Hict(headers) if headers is not None else self.requester.headers.copy()
         request["body"] = body if body is not None else b''
         if body is not None:  # body should be bytes
             if isinstance(body, str):
@@ -1127,7 +1157,7 @@ class Client():
         Usage:
         response = yield from .serviceWhileGen(tymeout=0.5)
 
-        Runs one iteration of serviceAll on next and yields empty
+        Runs one iteration of .service() on next and yields empty
         bytes while not done.
 
         Assumes associated tymist is advanced and realtime sleep delay
@@ -1146,3 +1176,131 @@ class Client():
                 raise ex
             yield b''  # this is eventually yielded by wsgi app while waiting
         return self.respond()
+
+
+def backendRequest(tymth, *,
+                   method=u'GET',
+                   scheme=u'',  #default if not in path
+                   host=u'localhost',  # default if not in path
+                   port=None, # default if not in path
+                   path=u'/',
+                   qargs=None,
+                   data=None,
+                   buffered=False,
+                   tymeout=2.0,
+                   ):
+    """
+    Perform Async ReST request to Backend Server
+
+    Parameters:
+
+    Usage: (Inside a generator function)
+
+        response = yield from backendRequest()
+
+    response is the response if valid else None
+    before response is completed the yield from yields up an empty string ''
+    once completed then response has a value
+
+    path can be full url with host port etc  path takes precedence over others
+
+
+    """
+    try:
+
+        if buffered:
+            wl = wiring.WireLog(name='backend', filed=True, samed=True)
+            wl.reopen()
+        else:
+            wl = None
+
+        headers = help.Hict([('Accept', 'application/json'),
+                             ('Connection', 'close')])
+
+        client = Client(bufsize=131072,
+                             wl=wl,
+                             scheme=scheme,
+                             hostname=host,
+                             port=port,
+                             method=method,
+                             path=path,
+                             qargs=qargs,
+                             headers=headers,
+                             data=data,
+                             tymeout=tymeout,
+                             reconnectable=False,
+                             tymth=tymth,
+                        )
+
+        client.transmit()
+        # assumes store clock is advanced elsewhere
+        tymer = tyming.Tymer(tymth=tymth, duration=tymeout)
+        while ((client.requests or client.connector.txbs or not client.responses)
+               and not tymer.expired):
+            try:
+                client.service()
+            except Exception as ex:
+                logger.error("Error: Servicing backend client. '{0}'\n".format(ex))
+                raise ex
+            yield b''  # yield from yields up to wsgi app while waiting
+
+        response = None  # in case timed out
+        if client.responses:
+            response = client.responses.popleft()
+
+    finally:
+        client.close()
+        if wl:
+            wl.close()
+
+    return response
+
+
+
+class ClientDoer(doing.Doer):
+    """
+    HTTP Client Doer
+
+    See Doer for inherited attributes, properties, and methods.
+
+    Attributes:
+       .client is HTTP Client instance
+
+    """
+
+    def __init__(self, client, **kwa):
+        """
+        Initialize instance.
+
+        Parameters:
+           client is HTTP Client instance
+        """
+        super(ClientDoer, self).__init__(**kwa)
+        self.client = client
+        if self.tymth:
+            self.client.wind(self.tymth)
+
+
+    def wind(self, tymth):
+        """
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
+        """
+        super(ClientDoer, self).wind(tymth)
+        self.client.wind(tymth)
+
+
+    def enter(self):
+        """"""
+        self.client.reopen()
+
+
+    def recur(self, tyme):
+        """"""
+        self.client.service()
+
+
+    def exit(self):
+        """"""
+        self.client.close()
+
